# Generated by roxygen2: do not edit by hand

S3method(AIC,xreg2)
S3method(ARE,data.frame)
S3method(ARE,matrix)
S3method(ARE,numeric)
S3method(ARE,two_numeric)
S3method(BIC,xreg2)
S3method(MAE,data.frame)
S3method(MAE,matrix)
S3method(MAE,numeric)
S3method(MAE,two_numeric)
S3method(MARE,data.frame)
S3method(MARE,matrix)
S3method(MARE,numeric)
S3method(MARE,two_numeric)
S3method(MBE,data.frame)
S3method(MBE,matrix)
S3method(MBE,numeric)
S3method(MBE,two_numeric)
S3method(RMSE,data.frame)
S3method(RMSE,matrix)
S3method(RMSE,numeric)
S3method(RMSE,two_numeric)
S3method(RMSRE,data.frame)
S3method(RMSRE,matrix)
S3method(RMSRE,numeric)
S3method(RMSRE,two_numeric)
S3method(ReMSE,data.frame)
S3method(ReMSE,matrix)
S3method(ReMSE,numeric)
S3method(ReMSE,two_numeric)
S3method(U95,data.frame)
S3method(U95,matrix)
S3method(U95,numeric)
S3method(U95,two_numeric)
S3method(appendmodel,formula)
S3method(c,xreg2Control)
S3method(c,xreg2ControlList)
S3method(change_target,formula)
S3method(erMAX,data.frame)
S3method(erMAX,matrix)
S3method(erMAX,numeric)
S3method(erMAX,two_numeric)
S3method(fisher_icc,data.frame)
S3method(fisher_icc,matrix)
S3method(fisher_icc,numeric)
S3method(fisher_icc,two_numeric)
S3method(just_CCC,data.frame)
S3method(just_CCC,matrix)
S3method(just_CCC,numeric)
S3method(just_CCC,two_numeric)
S3method(predict,xreg2)
S3method(print,xreg2)
S3method(summary,xreg2)
S3method(tstat,data.frame)
S3method(tstat,matrix)
S3method(tstat,numeric)
S3method(tstat,two_numeric)
export(ARE)
export(ARE_conform)
export(LCCC)
export(MAE)
export(MAPE)
export(MARE)
export(MBE)
export(RMSE)
export(RMSRE)
export(ReMSE)
export(ReMSE_conform)
export(U95)
export(combmean)
export(combmeans)
export(combmssds)
export(combsd)
export(combsds)
export(comp_table)
export(erMAX)
export(fisher_icc)
export(fixdist)
export(getMean)
export(getSD)
export(getVar)
export(getd)
export(getf)
export(getp)
export(getq)
export(getr)
export(is.wholenumber)
export(just_CCC)
export(ordD)
export(ordE)
export(ordEp)
export(pRMSE)
export(quant_fun)
export(quant_fun_groups)
export(quant_funs)
export(quant_funs_groups)
export(quant_funst)
export(rRMSE)
export(t_test2)
export(tstat)
export(xreg2_cont)
export(xreg2_cont_normal)
export(xreg2_cont_r_lnorm)
export(xreg2_cont_r_normal)
export(xreg2_control)
export(xreg2_dich_logistic)
export(xreg2_fit)
export(xreg2_fit_s)
export(xreg2_hyreg)
export(xreg2_optim)
importFrom(stats,AIC)
importFrom(stats,BIC)
importFrom(stats,aggregate)
importFrom(stats,as.formula)
importFrom(stats,complete.cases)
importFrom(stats,cor)
importFrom(stats,dbeta)
importFrom(stats,dexp)
importFrom(stats,dgamma)
importFrom(stats,dlnorm)
importFrom(stats,dnorm)
importFrom(stats,dweibull)
importFrom(stats,formula)
importFrom(stats,integrate)
importFrom(stats,na.omit)
importFrom(stats,optim)
importFrom(stats,pbeta)
importFrom(stats,pexp)
importFrom(stats,pgamma)
importFrom(stats,plnorm)
importFrom(stats,pnorm)
importFrom(stats,pt)
importFrom(stats,pweibull)
importFrom(stats,qnorm)
importFrom(stats,quantile)
importFrom(stats,sd)
importFrom(stats,var)
importFrom(utils,modifyList)
