#' @title xreg2: Flexible Maximum Likelihood Regression with Gradient-Based Optimisation
#'
#' @description Fits flexible maximum likelihood regression models supporting
#'   censored, interval, and hybrid continuous/dichotomous data. Provides
#'   explicit analytic and numerical gradient computation, random intercept
#'   models via Gauss-Hermite quadrature, and multiple distribution families.
#'
#' @keywords internal
"_PACKAGE"

#' @importFrom stats AIC BIC aggregate as.formula complete.cases cor
#'   dbeta dexp dgamma dlnorm dnorm dweibull formula integrate na.omit
#'   pbeta pexp pgamma plnorm pnorm pt pweibull qnorm quantile sd var
NULL
