% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/stat_methods.R
\name{ordEp}
\alias{ordEp}
\title{Order Statistic Expected Probabilities}
\usage{
ordEp(probs, n, par = c(mean = 0, sd = 1), dist = "normal")
}
\arguments{
\item{probs}{Numeric vector of rank proportions.}

\item{n}{Sample size.}

\item{par}{Named vector of distribution parameters.}

\item{dist}{Character distribution name.}
}
\value{
Numeric vector of probabilities.
}
\description{
Expected probability of order statistics
}
