% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ll_functions.R
\name{xreg2_dich_logistic}
\alias{xreg2_dich_logistic}
\title{Dichotomous Logistic Negative Log-Likelihood}
\usage{
xreg2_dich_logistic(par, dtalist)
}
\arguments{
\item{par}{Named numeric vector of current parameter values.}

\item{dtalist}{Internal data list produced by \code{xreg2_fit}.}
}
\value{
Scalar negative log-likelihood.
}
\description{
Computes the negative log-likelihood for a binary logistic
  regression model. Designed as a \code{p_fun} argument for
  \code{\link{xreg2_control}}.
}
\details{
Dichotomous logistic log-likelihood for xreg2
}
\examples{
# ctrl <- xreg2_control(formulas = list(y ~ INTERCEPT + x * SLOPE),
#                        p_fun = xreg2_dich_logistic,
#                        start_values = c(INTERCEPT = 0, SLOPE = 0))

}
