% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/stat_methods.R
\name{MBE}
\alias{MBE}
\alias{MBE.data.frame}
\alias{MBE.matrix}
\alias{MBE.numeric}
\title{Mean Bias Error}
\usage{
MBE(est, obs, ...)

\method{MBE}{data.frame}(est, obs, ...)

\method{MBE}{matrix}(est, obs, ...)

\method{MBE}{numeric}(est, obs, ...)
}
\arguments{
\item{est}{Numeric; estimates.}

\item{obs}{Numeric; observations.}

\item{...}{Passed to \code{mean}.}
}
\value{
Numeric MBE value.
}
\description{
Mean Bias Error
}
