% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/stat_methods.R
\name{ARE}
\alias{ARE}
\alias{ARE.data.frame}
\alias{ARE.matrix}
\alias{ARE.numeric}
\alias{ARE_conform}
\title{Average Relative Error}
\usage{
ARE(est, obs, absolute = FALSE, ...)

\method{ARE}{data.frame}(est, obs, absolute = FALSE, ...)

\method{ARE}{matrix}(est, obs, absolute = FALSE, ...)

\method{ARE}{numeric}(est, obs, absolute = FALSE, ...)

ARE_conform(dfys, dfobs, absolute = FALSE)
}
\arguments{
\item{est}{Numeric; estimates.}

\item{obs}{Numeric; observations.}

\item{absolute}{Logical; return absolute version. Default \code{FALSE}.}

\item{...}{Currently unused.}

\item{dfys}{Numeric matrix or data frame of estimates.}

\item{dfobs}{Numeric matrix or data frame of observations.}
}
\value{
Numeric ARE value.
}
\description{
Average Relative Error
}
