% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/stat_methods.R
\name{fixdist}
\alias{fixdist}
\title{Standardise Distribution Name}
\usage{
fixdist(dist)
}
\arguments{
\item{dist}{Character distribution name.}
}
\value{
Canonical short-form character name.
}
\description{
Maps common distribution name variants to their canonical R
  short form (e.g., \code{"normal"} -> \code{"norm"}).
}
\details{
Standardise distribution name
}
