% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/stat_methods.R
\name{RMSE}
\alias{RMSE}
\alias{RMSE.data.frame}
\alias{RMSE.matrix}
\alias{RMSE.numeric}
\alias{pRMSE}
\alias{rRMSE}
\title{Root Mean Square Error}
\usage{
RMSE(est, obs, percentage = FALSE, ...)

\method{RMSE}{data.frame}(est, obs, percentage = FALSE, ...)

\method{RMSE}{matrix}(est, obs, percentage = FALSE, ...)

\method{RMSE}{numeric}(est, obs, percentage = FALSE, ...)

pRMSE(est, obs, ...)

rRMSE(est, obs, ...)
}
\arguments{
\item{est}{Numeric; estimates.}

\item{obs}{Numeric; observations.}

\item{percentage}{Logical; return as percentage of mean. Default \code{FALSE}.}

\item{...}{Passed to \code{\link{RMSE}}.}
}
\value{
Numeric RMSE value.
}
\description{
Root Mean Square Error
}
