% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/stat_methods.R
\name{RMSRE}
\alias{RMSRE}
\alias{RMSRE.data.frame}
\alias{RMSRE.matrix}
\alias{RMSRE.numeric}
\title{Root Mean Square Relative Error}
\usage{
RMSRE(est, obs, ...)

\method{RMSRE}{data.frame}(est, obs, ...)

\method{RMSRE}{matrix}(est, obs, ...)

\method{RMSRE}{numeric}(est, obs, ...)
}
\arguments{
\item{est}{Numeric; estimates.}

\item{obs}{Numeric; observations.}

\item{...}{Currently unused.}
}
\value{
Numeric RMSRE value.
}
\description{
Root Mean Square Relative Error
}
