% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/stat_methods.R
\name{tstat}
\alias{tstat}
\alias{tstat.data.frame}
\alias{tstat.matrix}
\alias{tstat.numeric}
\title{t-Statistic}
\usage{
tstat(est, obs, ...)

\method{tstat}{data.frame}(est, obs, ...)

\method{tstat}{matrix}(est, obs, ...)

\method{tstat}{numeric}(est, obs, ...)
}
\arguments{
\item{est}{Numeric; estimates.}

\item{obs}{Numeric; observations.}

\item{...}{Currently unused.}
}
\value{
Numeric t-statistic.
}
\description{
t-statistic for model comparison
}
