% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/stat_methods.R
\name{getVar}
\alias{getVar}
\title{Variance of a distribution}
\usage{
getVar(qfun, pars)
}
\arguments{
\item{qfun}{Quantile function or character distribution name.}

\item{pars}{Named list of distribution parameters.}
}
\value{
Numeric variance.
}
\description{
Variance of a distribution
}
