% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/stat_methods.R
\name{combmssds}
\alias{combmssds}
\title{Combined mean, SD and n for multiple groups}
\usage{
combmssds(ms, ss, ns, na.rm = FALSE)
}
\arguments{
\item{ms}{Numeric vector of group means.}

\item{ss}{Numeric vector of group SDs.}

\item{ns}{Numeric vector of group sizes.}

\item{na.rm}{Logical.}
}
\value{
Matrix with columns n, mean, sd.
}
\description{
Combined mean, SD and n for multiple groups
}
