% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/stat_methods.R
\name{quant_fun}
\alias{quant_fun}
\title{Quantile Summary}
\usage{
quant_fun(
  x,
  statfuns = function(y) c(MEAN = mean(y, na.rm = TRUE), SE = sd(y, na.rm = TRUE)),
  probs = c(min = 0, `2.5\%` = 0.025, `25\%` = 0.25, median = 0.5, `75\%` = 0.75,
    `97.5\%` = 0.975, max = 1),
  names = TRUE
)
}
\arguments{
\item{x}{Numeric vector.}

\item{statfuns}{Function returning named summary statistics.}

\item{probs}{Named numeric vector of quantile probabilities.}

\item{names}{Logical; include names in quantile output.}
}
\value{
Named numeric vector of statistics and quantiles.
}
\description{
Computes summary statistics and quantiles for a numeric vector.
}
\details{
Quantile summary statistics
}
