% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/stat_methods.R
\name{MAE}
\alias{MAE}
\alias{MAE.data.frame}
\alias{MAE.matrix}
\alias{MAE.numeric}
\title{Mean Absolute Error}
\usage{
MAE(est, obs, ...)

\method{MAE}{data.frame}(est, obs, ...)

\method{MAE}{matrix}(est, obs, ...)

\method{MAE}{numeric}(est, obs, ...)
}
\arguments{
\item{est}{Numeric; estimates.}

\item{obs}{Numeric; observations.}

\item{...}{Passed to \code{mean}.}
}
\value{
Numeric MAE value.
}
\description{
Mean Absolute Error
}
