% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/stat_methods.R
\name{just_CCC}
\alias{just_CCC}
\alias{just_CCC.data.frame}
\alias{just_CCC.matrix}
\alias{just_CCC.numeric}
\title{Lin's CCC (simplified)}
\usage{
just_CCC(y, x, ...)

\method{just_CCC}{data.frame}(y, x, ...)

\method{just_CCC}{matrix}(y, x, ...)

\method{just_CCC}{numeric}(y, x, ...)
}
\arguments{
\item{y}{Numeric vector, matrix, or data frame.}

\item{x}{Numeric vector, matrix, or data frame.}

\item{...}{Passed to \code{\link{LCCC}}.}
}
\value{
Numeric CCC value.
}
\description{
Lin's concordance correlation coefficient (simplified)
}
