% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/stat_methods.R
\name{erMAX}
\alias{erMAX}
\alias{erMAX.data.frame}
\alias{erMAX.matrix}
\alias{erMAX.numeric}
\title{Maximum Absolute Relative Error}
\usage{
erMAX(est, obs, ...)

\method{erMAX}{data.frame}(est, obs, ...)

\method{erMAX}{matrix}(est, obs, ...)

\method{erMAX}{numeric}(est, obs, ...)
}
\arguments{
\item{est}{Numeric; estimates.}

\item{obs}{Numeric; observations.}

\item{...}{Currently unused.}
}
\value{
Numeric erMAX value.
}
\description{
Maximum Absolute Relative Error
}
