% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/methods.R
\name{summary.xreg2}
\alias{summary.xreg2}
\title{Summarise an xreg2 Model}
\usage{
\method{summary}{xreg2}(object, ...)
}
\arguments{
\item{object}{A fitted \code{xreg2} object.}

\item{...}{Currently unused.}
}
\value{
\code{object} invisibly.
}
\description{
Prints a detailed summary of a fitted \code{xreg2} model.
  Currently equivalent to \code{\link{print.xreg2}}.
}
\details{
Summary method for xreg2 objects
}
