% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/stat_methods.R
\name{ReMSE}
\alias{ReMSE}
\alias{ReMSE.data.frame}
\alias{ReMSE.matrix}
\alias{ReMSE.numeric}
\alias{ReMSE_conform}
\title{Relative Mean Squared Error}
\usage{
ReMSE(est, obs, trueobs, ...)

\method{ReMSE}{data.frame}(est, obs, trueobs, ...)

\method{ReMSE}{matrix}(est, obs, trueobs, ...)

\method{ReMSE}{numeric}(est, obs, trueobs, ...)

ReMSE_conform(dfys, dfobs, trueobs)
}
\arguments{
\item{est}{Numeric; estimates.}

\item{obs}{Numeric; observations.}

\item{trueobs}{Numeric; true values.}

\item{...}{Currently unused.}

\item{dfys}{Numeric matrix or data frame of estimates.}

\item{dfobs}{Numeric matrix or data frame of observations.}
}
\value{
Numeric ReMSE value.
}
\description{
Relative Mean Squared Error
}
