% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/stat_methods.R
\name{is.wholenumber}
\alias{is.wholenumber}
\title{Test for Whole Number}
\usage{
is.wholenumber(x, tol = .Machine$double.eps^0.5)
}
\arguments{
\item{x}{Numeric vector.}

\item{tol}{Numeric tolerance. Default \code{.Machine$double.eps^0.5}.}
}
\value{
Logical vector.
}
\description{
Tests whether numeric values are whole numbers within a
  numeric tolerance.
}
\details{
Test for whole number
}
