% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/stat_methods.R
\name{combsd}
\alias{combsd}
\title{Combined standard deviation of two groups}
\usage{
combsd(m1, m2, s1, s2, n1, n2, na.rm = FALSE)
}
\arguments{
\item{m1}{Mean of group 1.}

\item{m2}{Mean of group 2.}

\item{s1}{SD of group 1.}

\item{s2}{SD of group 2.}

\item{n1}{Size of group 1.}

\item{n2}{Size of group 2.}

\item{na.rm}{Logical.}
}
\value{
Combined SD.
}
\description{
Combined standard deviation of two groups
}
