% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/stat_methods.R
\name{ordE}
\alias{ordE}
\title{Order Statistic Expected Value}
\usage{
ordE(r, n, par = c(mean = 0, sd = 1), dist = "norm", log = FALSE)
}
\arguments{
\item{r}{Integer rank (or vector of ranks).}

\item{n}{Sample size.}

\item{par}{Named vector of distribution parameters.}

\item{dist}{Character distribution name.}

\item{log}{Currently unused.}
}
\value{
Numeric expected value.
}
\description{
Computes the expected value of the \eqn{r}-th order statistic
  in a random sample of \eqn{n} from a given distribution.
}
\details{
Expected value of an order statistic
}
