% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/stat_methods.R
\name{MAPE}
\alias{MAPE}
\alias{MARE}
\alias{MARE.data.frame}
\alias{MARE.matrix}
\alias{MARE.numeric}
\title{Mean Absolute Relative Error (MARE / MAPE)}
\usage{
MAPE(est, obs, ...)

MARE(est, obs, ...)

\method{MARE}{data.frame}(est, obs, ...)

\method{MARE}{matrix}(est, obs, ...)

\method{MARE}{numeric}(est, obs, ...)
}
\arguments{
\item{est}{Numeric; estimates.}

\item{obs}{Numeric; observations.}

\item{...}{Currently unused.}
}
\value{
Numeric MARE value.
}
\description{
Mean Absolute Relative Error / Mean Absolute Percentage Error
}
