% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/stat_methods.R
\name{U95}
\alias{U95}
\alias{U95.data.frame}
\alias{U95.matrix}
\alias{U95.numeric}
\title{Uncertainty at 95 Percent}
\usage{
U95(est, obs, ...)

\method{U95}{data.frame}(est, obs, ...)

\method{U95}{matrix}(est, obs, ...)

\method{U95}{numeric}(est, obs, ...)
}
\arguments{
\item{est}{Numeric; estimates.}

\item{obs}{Numeric; observations.}

\item{...}{Passed to \code{var} and \code{sqrt}.}
}
\value{
Numeric U95 value.
}
\description{
Uncertainty at 95 Percent
}
