% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ll_functions.R
\name{xreg2_cont}
\alias{xreg2_cont}
\title{General Continuous Negative Log-Likelihood}
\usage{
xreg2_cont(
  par,
  dtalist,
  log.p = TRUE,
  aggregate.p = TRUE,
  print_pars = FALSE,
  dist = "normal"
)
}
\arguments{
\item{par}{Named numeric vector of current parameter values.}

\item{dtalist}{Internal data list produced by \code{xreg2_fit}.}

\item{log.p}{Logical; use log-scale probabilities. Default \code{TRUE}.}

\item{aggregate.p}{Logical; return scalar negloglik. Default \code{TRUE}.}

\item{print_pars}{Logical; print parameters and value. Default \code{FALSE}.}

\item{dist}{Character; distribution family. One of \code{"normal"},
\code{"lognormal"}, \code{"exp"}/\code{"exponential"}, \code{"beta"},
\code{"gamma"}, \code{"weibull"}. Default \code{"normal"}.}
}
\value{
Scalar negative log-likelihood (when \code{aggregate.p = TRUE}).
}
\description{
Computes the negative log-likelihood for a censored/interval
  regression model supporting multiple distributions (normal, lognormal,
  exponential, beta, gamma, weibull). Designed as a \code{p_fun} argument
  for \code{\link{xreg2_control}}.
}
\details{
General continuous log-likelihood for xreg2
}
\examples{
# ctrl <- xreg2_control(formulas = list(y ~ INTERCEPT + x * SLOPE),
#                        p_fun = xreg2_cont,
#                        start_values = c(INTERCEPT = 0, SLOPE = 0, LN_SIGMA = 0))

}
