% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/methods.R
\name{print.xreg2}
\alias{print.xreg2}
\title{Print an xreg2 Model}
\usage{
\method{print}{xreg2}(x, ...)
}
\arguments{
\item{x}{A fitted \code{xreg2} object.}

\item{...}{Currently unused.}
}
\value{
\code{x} invisibly.
}
\description{
Prints a concise summary of a fitted \code{xreg2} model,
  including coefficients, standard errors, and minimised negative
  log-likelihoods.
}
\details{
Print method for xreg2 objects
}
