% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/stat_methods.R
\name{combmean}
\alias{combmean}
\title{Combined mean of two groups}
\usage{
combmean(m1, m2, n1 = NULL, n2 = NULL, na.rm = FALSE)
}
\arguments{
\item{m1}{Mean of group 1 (scalar or vector).}

\item{m2}{Mean of group 2 (scalar or vector).}

\item{n1}{Size of group 1.}

\item{n2}{Size of group 2.}

\item{na.rm}{Logical.}
}
\value{
Combined mean.
}
\description{
Combined mean of two groups
}
