% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/stat_methods.R
\name{fisher_icc}
\alias{fisher_icc}
\alias{fisher_icc.data.frame}
\alias{fisher_icc.matrix}
\alias{fisher_icc.numeric}
\title{Fisher's ICC}
\usage{
fisher_icc(y, x, ...)

\method{fisher_icc}{data.frame}(y, x, ...)

\method{fisher_icc}{matrix}(y, x, ...)

\method{fisher_icc}{numeric}(y, x, ...)
}
\arguments{
\item{y}{Numeric vector, matrix, or data frame.}

\item{x}{Numeric vector, matrix, or data frame.}

\item{...}{Currently unused.}
}
\value{
Numeric ICC value.
}
\description{
Computes Fisher's intraclass correlation coefficient between
  two numeric vectors or matrices.
}
\details{
Fisher's intraclass correlation coefficient
}
