% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/stat_methods.R
\name{getMean}
\alias{getMean}
\title{Mean of a distribution}
\usage{
getMean(qfun, pars)
}
\arguments{
\item{qfun}{Quantile function.}

\item{pars}{Named list of distribution parameters.}
}
\value{
Numeric mean.
}
\description{
Mean of a distribution
}
