% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/stat_methods.R
\name{ordD}
\alias{ordD}
\title{Order Statistic Density}
\usage{
ordD(x, r, n, par = c(mean = 0, sd = 1), dist = "norm", log = FALSE)
}
\arguments{
\item{x}{Numeric vector of values.}

\item{r}{Integer rank.}

\item{n}{Sample size.}

\item{par}{Named vector of distribution parameters.}

\item{dist}{Character distribution name.}

\item{log}{Logical; return log-density. Default \code{FALSE}.}
}
\value{
Numeric density (or log-density).
}
\description{
Computes the density of the \eqn{r}-th order statistic in a
  random sample of \eqn{n} from a given distribution.
}
\details{
Density for an order statistic
}
